==> ejc-zdsmaterialb-impl-3.0.0-20251031.063934-75-sources.jar: com/ejianc/business/zdsmaterial/material/bean/MatInvoiceOcrEntity.java <==
package com.ejianc.business.zdsmaterial.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购发票登记-OCR附件
 * 
 * @author generator
 * 
 */
 @TableName("ejc_material_mat_invoice_ocr")
public class MatInvoiceOcrEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="main_id")
    private Long mainId; // 主表id
    @TableField(value="file_type")
    private String fileType; // 附件类型
    @TableField(value="file_id")
    private Long fileId; // 附件id
    @TableField(value="file_name")
    private String fileName; // 附件名称
    @TableField(value="file_url")
    private String fileUrl; // 附件地址
    @TableField(value="size")
    private String size; // 大小
    @TableField(value="upload_time")
    private Date uploadTime; // 上传时间
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="upload_person")
    private String uploadPerson; // 上传人
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_main_id")
    private Long sourceMainId; // 来源主表id
    @TableField(value="invoice_code")
    private String invoiceCode; // 发票代码
    @TableField(value="invoice_number")
    private String invoiceNumber; // 发票号码
    @TableField(value="invoice_date")
    private Date invoiceDate; // 开票日期
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="invoice_mny")
    private BigDecimal invoiceMny; // 发票金额(无税)
    @TableField(value="invoice_tax")
    private BigDecimal invoiceTax; // 税额
    @TableField(value="invoice_tax_mny")
    private BigDecimal invoiceTaxMny; // 发票金额
    @TableField(value="ocr_msg")
    private String ocrMsg; // OCR识别结果
    @TableField(value="identify_result")
    private String identifyResult; // 发票识别结果：发票文件上传到阿里云，阿里云识别发票内容后返回的识别数据，大json串
    
    
    

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public Long getFileId() {
        return fileId;
    }

    public void setFileId(Long fileId) {
        this.fileId = fileId;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileUrl() {
        return fileUrl;
    }

    public void setFileUrl(String fileUrl) {
        this.fileUrl = fileUrl;
    }
    public String getSize() {
        return size;
    }

    public void setSize(String size) {
        this.size = size;
    }
    public Date getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Date uploadTime) {
        this.uploadTime = uploadTime;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getUploadPerson() {
        return uploadPerson;
    }

    public void setUploadPerson(String uploadPerson) {
        this.uploadPerson = uploadPerson;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceMainId() {
        return sourceMainId;
    }

    public void setSourceMainId(Long sourceMainId) {
        this.sourceMainId = sourceMainId;
    }
    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    public void setInvoiceDate(Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    public void setInvoiceMny(BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }
    public BigDecimal getInvoiceTax() {
        return invoiceTax;
    }

    public void setInvoiceTax(BigDecimal invoiceTax) {
        this.invoiceTax = invoiceTax;
    }
    public BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    public void setInvoiceTaxMny(BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }
    public String getOcrMsg() {
        return ocrMsg;
    }

    public void setOcrMsg(String ocrMsg) {
        this.ocrMsg = ocrMsg;
    }
    public String getIdentifyResult() {
        return identifyResult;
    }

    public void setIdentifyResult(String identifyResult) {
        this.identifyResult = identifyResult;
    }
    
}

==> ejc-zdsmaterialb-impl-3.0.0-20251205.093559-99-sources.jar: com/ejianc/business/zdsmaterial/material/bean/MatInvoiceOcrEntity.java <==
package com.ejianc.business.zdsmaterial.material.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 采购发票登记-OCR附件
 * 
 * @author generator
 * 
 */
 @TableName("ejc_material_mat_invoice_ocr")
public class MatInvoiceOcrEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="main_id")
    private Long mainId; // 主表id
    @TableField(value="file_type")
    private String fileType; // 附件类型
    @TableField(value="file_id")
    private Long fileId; // 附件id
    @TableField(value="file_name")
    private String fileName; // 附件名称
    @TableField(value="file_url")
    private String fileUrl; // 附件地址
    @TableField(value="size")
    private String size; // 大小
    @TableField(value="upload_time")
    private Date uploadTime; // 上传时间
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="upload_person")
    private String uploadPerson; // 上传人
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_main_id")
    private Long sourceMainId; // 来源主表id
    @TableField(value="invoice_code")
    private String invoiceCode; // 发票代码
    @TableField(value="invoice_number")
    private String invoiceNumber; // 发票号码
    @TableField(value="invoice_date")
    private Date invoiceDate; // 开票日期
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="invoice_mny")
    private BigDecimal invoiceMny; // 发票金额(无税)
    @TableField(value="invoice_tax")
    private BigDecimal invoiceTax; // 税额
    @TableField(value="invoice_tax_mny")
    private BigDecimal invoiceTaxMny; // 发票金额
    @TableField(value="ocr_msg")
    private String ocrMsg; // OCR识别结果
    @TableField(value="identify_result")
    private String identifyResult; // 发票识别结果：发票文件上传到阿里云，阿里云识别发票内容后返回的识别数据，大json串
    
    
    

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public Long getFileId() {
        return fileId;
    }

    public void setFileId(Long fileId) {
        this.fileId = fileId;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileUrl() {
        return fileUrl;
    }

    public void setFileUrl(String fileUrl) {
        this.fileUrl = fileUrl;
    }
    public String getSize() {
        return size;
    }

    public void setSize(String size) {
        this.size = size;
    }
    public Date getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Date uploadTime) {
        this.uploadTime = uploadTime;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getUploadPerson() {
        return uploadPerson;
    }

    public void setUploadPerson(String uploadPerson) {
        this.uploadPerson = uploadPerson;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceMainId() {
        return sourceMainId;
    }

    public void setSourceMainId(Long sourceMainId) {
        this.sourceMainId = sourceMainId;
    }
    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    public void setInvoiceDate(Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getInvoiceMny() {
        return invoiceMny;
    }

    public void setInvoiceMny(BigDecimal invoiceMny) {
        this.invoiceMny = invoiceMny;
    }
    public BigDecimal getInvoiceTax() {
        return invoiceTax;
    }

    public void setInvoiceTax(BigDecimal invoiceTax) {
        this.invoiceTax = invoiceTax;
    }
    public BigDecimal getInvoiceTaxMny() {
        return invoiceTaxMny;
    }

    public void setInvoiceTaxMny(BigDecimal invoiceTaxMny) {
        this.invoiceTaxMny = invoiceTaxMny;
    }
    public String getOcrMsg() {
        return ocrMsg;
    }

    public void setOcrMsg(String ocrMsg) {
        this.ocrMsg = ocrMsg;
    }
    public String getIdentifyResult() {
        return identifyResult;
    }

    public void setIdentifyResult(String identifyResult) {
        this.identifyResult = identifyResult;
    }
    
}
